---
url: https://www.normattiva.it/uri-res/N2Ls?urn:nir:stato:legge:1986-06-21;317
url_xml: https://www.normattiva.it/do/atto/caricaAKN?dataGU=19860702&codiceRedaz=086U0317&dataVigenza=20251104
dataGU: 19860702
codiceRedaz: 086U0317
dataVigenza: 20251104
---

# ((Disposizioni
di attuazione di disciplina europea in materia di normazione europea
e procedura d'informazione nel settore delle regolamentazioni
tecniche e delle regole relative ai servizi della societa'
dell'informazione.))

La Camera dei deputati ed il Senato della Repubblica hanno

approvato;

IL PRESIDENTE DELLA REPUBBLICA

PROMULGA la seguente legge:

## Art. 1. - ((Definizioni))

((Ai fini della presente legge, oltre alle definizioni contenute nel regolamento (UE) n. 1025/2012 del Parlamento europeo e del Consiglio, del 25 ottobre 2012, si applicano le seguenti definizioni: a) prodotto: i prodotti di fabbricazione industriale e i prodotti agricoli, compresi i prodotti della pesca; b) servizio: ai fini dell'applicazione della disciplina in materia di normazione, qualsiasi attivita' economica non salariata, quale definita all'articolo 57 del Trattato sul funzionamento dell'Unione europea (TFUE); ovvero, ai fini dell'applicazione della procedura di informazione di cui all'articolo 1-bis della presente legge, qualsiasi servizio della societa' dell'informazione, vale a dire qualsiasi servizio prestato normalmente dietro retribuzione, a distanza, per via elettronica e a richiesta individuale di un destinatario di servizi; ai fini della presente definizione si intende per: 1) a distanza: un servizio fornito senza la presenza simultanea delle parti; 2) per via elettronica: un servizio inviato all'origine e ricevuto a destinazione mediante attrezzature elettroniche di trattamento, compresa la compressione digitale, e di memorizzazione di dati, e che e' interamente trasmesso, inoltrato e ricevuto mediante fili, radio, mezzi ottici o altri mezzi elettromagnetici; 3) a richiesta individuale di un destinatario di servizi: un servizio fornito mediante trasmissione di dati su richiesta individuale; c) specificazione tecnica: una specificazione che figura in un documento che definisce le caratteristiche richieste di un prodotto, quali i livelli di qualita' o di proprieta' di utilizzazione, la sicurezza, le dimensioni, comprese le prescrizioni applicabili al prodotto per quanto riguarda la denominazione di vendita, la terminologia, i simboli, le prove ed i metodi di prova, l'imballaggio, la marcatura e l'etichettatura, nonche' le procedure di valutazione della conformita'; il termine "specificazione tecnica" comprende anche i metodi e i procedimenti di produzione relativi ai prodotti agricoli ai sensi dell'articolo 38, paragrafo 1, secondo comma, del Trattato sul funzionamento dell'Unione europea, ai prodotti destinati all'alimentazione umana e animale, nonche' ai medicinali definiti all'articolo 1 della direttiva 2001/83/CE del Parlamento europeo e del Consiglio, come attuata dal decreto legislativo 24 aprile 2006, n. 219, cosi' come i metodi e i procedimenti di produzione relativi agli altri prodotti, quando abbiano un'incidenza sulle caratteristiche di questi ultimi; d) altro requisito: un requisito diverso da una specificazione tecnica, prescritto per un prodotto per motivi di tutela, in particolare dei consumatori o dell'ambiente, e concernente il suo ciclo di vita dopo la commercializzazione, quali le sue condizioni di utilizzazione, di riciclaggio, di reimpiego o di eliminazione, qualora tali condizioni possano influenzare in modo significativo la composizione o la natura del prodotto o la sua commercializzazione; e) regola relativa ai servizi: un requisito di natura generale relativo all'accesso alle attivita' di servizio di cui alla lettera b) e al loro esercizio, in particolare le disposizioni relative al prestatore di servizi, ai servizi e al destinatario di servizi, ad esclusione delle regole che non riguardano specificamente i servizi ivi definiti; ai fini della presente definizione: 1) una regola si considera riguardante specificamente i servizi della societa' dell'informazione quando, alla luce della sua motivazione e del testo del relativo dispositivo, essa si pone come finalita' e obiettivo specifici, nel suo insieme o in alcune disposizioni puntuali, di disciplinare in modo esplicito e mirato tali servizi; 2) una regola non si considera riguardante specificamente i servizi della societa' dell'informazione se essa riguarda tali servizi solo in modo implicito o incidentale; f) regola tecnica: una specificazione tecnica o altro requisito o una regola relativa ai servizi, comprese le disposizioni amministrative che ad esse si applicano, la cui osservanza e' obbligatoria, de iure o de facto, per la commercializzazione, la prestazione di servizi, lo stabilimento di un fornitore di servizi o l'utilizzo degli stessi in uno Stato membro dell'Unione europea o in una parte importante di esso, nonche', fatte salve quelle di cui all'articolo 9-ter, le disposizioni legislative, regolamentari o amministrative che vietano la fabbricazione, l'importazione, la commercializzazione o l'utilizzo di un prodotto oppure la prestazione o l'utilizzo di un servizio o lo stabilimento come fornitore di servizi; costituiscono in particolare regole tecniche de facto: 1) le disposizioni legislative, regolamentari o amministrative che fanno riferimento o a specificazioni tecniche o ad altri requisiti o a regole relative ai servizi, o a codici professionali o di buona prassi che si riferiscono a loro volta a specificazioni tecniche o ad altri requisiti ovvero a regole relative ai servizi e la cui osservanza conferisce una presunzione di conformita' alle prescrizioni fissate dalle suddette disposizioni legislative, regolamentari o amministrative; 2) gli accordi facoltativi dei quali l'autorita' pubblica e' parte contraente e che, nell'interesse generale mirano al rispetto di specificazioni tecniche o di altri requisiti, o di regole relative ai servizi, ad eccezione del capitolato degli appalti pubblici; 3) le specificazioni tecniche o altri requisiti o le regole relative ai servizi connessi con misure di carattere fiscale o finanziario che influenzano il consumo di prodotti o di servizi promuovendo l'osservanza di tali specificazioni tecniche o altri requisiti o regole relative ai servizi; non sono contemplati le specificazioni tecniche, o altri requisiti o le regole relative ai servizi connessi con i regimi nazionali di sicurezza sociale, ove stabilite dalle autorita' designate dagli Stati membri e incluse in un elenco stabilito e aggiornato, all'occorrenza da parte della Commissione nell'ambito del comitato di cui all'articolo 2 della direttiva (UE) 2015/1535; g) progetto di regola tecnica: il testo di una specificazione tecnica o di un altro requisito o di una regola relativa ai servizi, comprendente anche disposizioni amministrative, elaborato per adottarlo o farlo adottare come regola tecnica e che si trova in una fase preparatoria in cui e' ancora possibile apportarvi modificazioni sostanziali; h) programma di lavoro: il programma di lavoro predisposto almeno una volta l'anno da uno degli organismi nazionali di normazione in conformita' alle prescrizioni di cui all'articolo 3 del regolamento (UE) n. 1025/2012; i) Unita' centrale di notifica: ai fini dell'applicazione della procedura di informazione di cui all'articolo 1-bis, l'ufficio dirigenziale indicato nel decreto ministeriale di individuazione degli uffici dirigenziali non generali, nell'ambito della Direzione generale cui e' attribuita la relativa competenza dal regolamento di organizzazione del Ministero dello sviluppo economico; l) data di notifica: la data in cui la Commissione europea ha ricevuto la comunicazione di cui all'articolo 5-bis, comma 1, corredata della documentazione prescritta, attraverso il sistema pratico scelto dalla Commissione in attuazione dell'articolo 3, paragrafo 4, lettera a), della direttiva (UE) 2015/1535 per lo scambio di informazioni; m) testo definitivo di una regola tecnica: il testo di un progetto di regola tecnica comunicato alla Commissione ai sensi dell'articolo 5-bis, che e' stato approvato definitivamente dal o dai soggetti istituzionali dotati dell'autorita' di apportarvi modificazioni sostanziali; n) data di adozione di una regola tecnica: la data in cui il testo di un progetto di regola tecnica comunicato alla Commissione ai sensi dell'articolo 5-bis, e' approvato definitivamente dal o dai soggetti istituzionale dotati dell'autorita' di apportarvi modificazioni sostanziali; o) data di pubblicazione ufficiale di una regola tecnica: la data in cui il testo definitivo di un progetto di regola tecnica e' pubblicato nella Gazzetta Ufficiale della Repubblica italiana ovvero nel sito istituzionale dell'Amministrazione o Autorita' che la ha adottata.))

## Art. 1-bis. - (Ambito di applicazione della procedura di informazione).

1. I progetti di regole tecniche sono sottoposti alla procedura d'informazione di cui alla presente legge.

((

2. La procedura d'informazione di cui al comma 1 non si applica:

- a) ai servizi non contemplati dalla specifica definizione di cui all'articolo 1, comma 1, lettera b), per quanto riguarda i servizi della societa' dell'informazione, ed in particolare a quelli compresi nell'elenco indicativo di cui all'allegato I;
- b) ai servizi di radiodiffusione sonora;
- c) ai servizi di radiodiffusione televisiva di cui all'articolo 1, paragrafo 1, lettera e), della direttiva 2010/13/UE del Parlamento europeo e del Consiglio, come attuata nell'articolo 2 del Testo unico dei servizi di media audiovisivi e radiofonici di cui al decreto legislativo 31 luglio 2005, n. 177, e successive modificazioni;
- d) alle regole concernenti questioni che costituiscono oggetto di una normativa dell'Unione in materia di servizi di telecomunicazione, di cui alla direttiva 2002/21/CE del Parlamento europeo e del Consiglio, come attuata nell'ambito del codice delle comunicazioni elettroniche di cui al decreto legislativo 1° agosto 2003, n. 259, e successive modificazioni;
- e) alle regole concernenti questioni che costituiscono oggetto di una normativa dell'Unione europea in materia di servizi finanziari, quali elencati in modo non esauriente nell'allegato II della presente legge;
- f) salvo quanto previsto all'articolo 9-bis, comma 8, alle regole emanate dai o per i mercati regolamentati a norma della direttiva 2004/39/CE del Parlamento europeo e del Consiglio, come attuata nell'ambito del Testo unico delle disposizioni in materia di intermediazione finanziaria di cui al decreto legislativo 24 febbraio 1998, n. 58, e successive modificazioni, o emanate da o per altri mercati o organi che effettuano operazioni di compensazione o di pagamento su tali mercati;
- g) alle misure che gli Stati membri ritengono necessarie nel contesto dei trattati per garantire la protezione delle persone, e segnatamente dei lavoratori, in occasione dell'impiego di prodotti, a condizione che tali misure non influiscano sui prodotti stessi.

))

## Art. 2.

(( ARTICOLO ABROGATO DALLA L. 6 FEBBRAIO 1996, N.52 ))

## Art. 3.

(Nomine di rappresentanti dello Stato nel ((Comitati della Commissione europea)) ). ((

1. I rappresentanti dello Stato italiano nel comitato permanente di cui agli articoli 2 e 3 della direttiva (UE) 2015/1535, nonche' nel comitato di cui all'articolo 22 del regolamento (UE) n. 1025/2012, sono designati, rispettivamente, dal Ministero dello sviluppo economico e, ove occorra, dal Ministero delle infrastrutture e dei trasporti, dal Ministero del lavoro e delle politiche sociali, dal Ministero delle politiche agricole, alimentari e forestali e dal Ministero dell'interno, nell'ambito dei dirigenti e funzionari delle direzioni generali specificamente competenti e di esperti altamente specializzati. La designazione e' comunicata alle competenti autorita' europee per il tramite del Ministero degli affari esteri e della cooperazione internazionale.

2. I rappresentanti di cui al comma 1 coordinano la propria attivita' con le altre amministrazioni pubbliche interessate, anche mediante la periodica convocazione di conferenze di servizi con i rappresentanti delle amministrazioni interessate.

((

3. Possono essere designati, di volta in volta, in casi particolari, funzionari di amministrazioni pubbliche ed esperti altamente specializzati su specifici argomenti da trattare in seno ai comitati di cui al comma 1.

))

## Art. 4. - (( (Organismi nazionali di normazione italiani).))

((

1. L'individuazione e le modifiche degli organismi nazionali di normazione italiani sono comunicate alla Commissione europea dal Ministero dello sviluppo economico, previo decreto interministeriale adottato dal Ministro dello sviluppo economico, di concerto con i Ministri degli affari esteri e della cooperazione internazionale, del lavoro e delle politiche sociali, delle infrastrutture e dei trasporti, nonche' dell'istruzione, dell'universita' e della ricerca, delle politiche agricole, alimentari e forestali e dell'interno. La vigilanza sugli organismi di cui al primo periodo e' esercitata dal Ministero dello sviluppo economico, che puo' a tal fine acquisire il parere del Consiglio nazionale delle ricerche e, limitatamente al settore dell'ingegneria civile e strutturale, anche il parere del Ministero delle infrastrutture e dei trasporti e del Consiglio superiore dei lavori pubblici e, limitatamente al settore della sicurezza in caso di incendio, anche il parere del Ministero dell'interno.

2. L'Ente nazionale italiano di unificazione (UNI), il Comitato elettrotecnico italiano (CEI), nonche', relativamente alle attivita' da svolgere in rapporto con l'Istituto europeo per le norme di telecomunicazione - ETSI e l'Unione internazionale delle telecomunicazioni (UIT), congiuntamente l'UNI ed il CEI sulla base di appositi accordi di collaborazione con l'Istituto superiore delle comunicazioni e delle tecnologie dell'informazione (ISCOM), elencati nell'allegato II della direttiva 98/34/CE abrogata dall'articolo 10 della direttiva (UE) 2015/1535, continuano ad operare quali organismi nazionali di normazione italiani come individuati alla data di entrata in vigore del presente articolo))

## Art. 5. - (( (Adempimenti degli organismi nazionali di normazione italiani).))

((

1. Gli organismi nazionali di normazione italiani operano nel rispetto delle disposizioni del regolamento (UE) n. 1025/2012 e, in particolare, degli obblighi di trasparenza di cui all'articolo 4 di tale regolamento e dell'obbligo di incoraggiare e facilitare l'accesso delle piccole e medie imprese alle norme ed ai processi di sviluppo delle stesse di cui all'articolo 6 del medesimo regolamento. Almeno una volta ogni anno ciascun organismo nazionale di normazione italiano stabilisce il proprio programma di lavoro che contiene le informazioni sulle norme che l'organismo stesso intende elaborare o modificare, che sta preparando o modificando e che ha adottato nel periodo del programma di lavoro precedente, a meno che non si tratti di recepimenti identici o equivalenti di norme internazionali o europee. Il programma di lavoro indica, in relazione ad ogni norma:

- a) l'oggetto;
- b) la fase raggiunta nell'elaborazione;
- c) i riferimenti a eventuali norme internazionali sulle quali ci si e' basati.

2. Gli organismi nazionali di normazione italiani rendono disponibile il proprio programma di lavoro sul proprio sito web e diffondono un avviso relativo all'esistenza di tale programma almeno in una pubblicazione nazionale sulle attivita' di normazione. I medesimi organismi, al piu' tardi al momento della pubblicazione del programma di lavoro, notificano l'esistenza del programma alle organizzazioni europee di normazione, agli altri organismi nazionali di normazione e alla Commissione europea.

3. Se la Commissione europea o le organizzazioni europee di normazione comunicano l'intenzione di trattare a livello europeo e secondo le norme definite dalle organizzazioni europee di normazione, un oggetto di lavoro compreso nel programma annuale di lavoro degli organismi nazionali di normazione italiani, questi ultimi non si oppongono a tale iniziativa e non intraprendono alcuna azione che possa pregiudicare una decisione in merito.

4. Durante l'elaborazione di una norma armonizzata, o successivamente alla sua approvazione, gli organismi nazionali di normazione italiani non intraprendono alcuna azione che puo' recare pregiudizio per l'armonizzazione auspicata e, in particolare, si astengono dal pubblicare, in riferimento al settore in questione, una norma nazionale nuova o riveduta che non sia completamente in linea con una norma armonizzata esistente. A seguito della pubblicazione di una norma armonizzata tutte le norme nazionali in contrasto con la stessa sono ritirate entro un termine ragionevole.

5. Gli organismi nazionali di normazione italiani e le amministrazioni interessate trasmettono all'Unita' centrale di notifica, ai fini della immediata comunicazione alla Commissione europea conformemente all'articolo 5-bis, comma 1, tutte le richieste che tali amministrazioni pubbliche hanno presentato ad un organismo nazionale di normazione italiano volte ad elaborare specifiche tecniche o una norma per prodotti specifici, in previsione dell'emanazione di una regola tecnica per tali prodotti come progetto di regola tecnica e indicano i motivi che ne giustificano la formulazione.

6. Gli organismi nazionali di normazione italiani trasmettono le informazioni ricevute dagli organismi nazionali di normazione degli altri Stati membri dell'Unione europea, dal Comitato europeo di normazione - CEN, dall'ETSI e dal Comitato europeo di normazione elettrotecnica - CENELEC, al Ministero dello sviluppo economico e, limitatamente al settore dell'ingegneria civile e strutturale, al Servizio tecnico centrale del Consiglio superiore dei lavori pubblici nonche', limitatamente al settore della sicurezza in caso di incendio, alla Direzione centrale prevenzione e sicurezza tecnica del Dipartimento dei vigili del fuoco, del soccorso pubblico e della difesa civile del Ministero dell'interno.

))

## Art. 5-bis. - (( (Adempimenti delle amministrazioni pubbliche italiane ai fini dell'adozione di regole tecniche).))

((

1. Fatto salvo l'articolo 9-ter, ogni progetto di regola tecnica e' immediatamente trasmesso, da parte dell'amministrazione con competenza prevalente per la sua adozione, all'Unita' centrale di notifica ai fini della successiva immediata comunicazione alla Commissione europea ai sensi della direttiva (UE) 2015/1535, salvo che si tratti del semplice recepimento integrale di una norma internazionale o europea, nel qual caso e' sufficiente corredare il progetto dell'atto con cui si dispone l'adozione della norma con una semplice informazione sulla norma stessa. L'amministrazione competente procede ad una nuova trasmissione all'Unita' centrale di notifica ai fini di una nuova comunicazione alla Commissione europea del progetto di regola tecnica quando al progetto stesso sono apportate modifiche importanti che ne alterano l'ambito di applicazione, ne abbreviano il calendario di applicazione inizialmente previsto, aggiungono o rendono piu' rigorosi le specificazioni o i requisiti.

2. Per consentire all'Unita' centrale di notifica di effettuare la comunicazione di cui al comma 1 completa di tutti gli elementi e documenti prescritti dalla direttiva (UE) 2015/1535, l'amministrazione trasmette alla stessa il progetto di regola tecnica corredato da:

- a) apposita relazione recante l'enunciazione dei motivi della sua adozione, evidenziando anche se gli stessi risultano gia' dal progetto;
- b) nei casi di cui al comma 10, la documentazione e tutti gli elementi di informazione ivi previsti;
- c) eventuale motivata richiesta di riservatezza alla quale l'Unita' centrale di notifica si conforma nel provvedere alla procedura di informazione di cui alla presente legge;
- d) il testo delle disposizioni legislative e regolamentari fondamentali, essenzialmente e direttamente in questione, quando la conoscenza di detto testo e' necessario per valutare la portata del progetto di regola tecnica; se tale testo e' gia' stato trasmesso in relazione con una comunicazione precedente, e' sufficiente indicare gli estremi di detta comunicazione;
- e) nei casi di urgenza indicati nell'articolo 9, comma 6, la richiesta di procedura d'urgenza accompagnata da un'esauriente relazione sulla situazione grave ed imprevedibile o i gravi rischi per la sicurezza ed integrita' del sistema finanziario che la giustificano ai sensi dell'articolo 6, paragrafo 7, lettera a) o b), della direttiva (UE) 2015/1535;
- f) eventuale richiesta di notifica del progetto di regola tecnica anche ai sensi di altri atti dell'Unione europea che prevedono procedure di notifica;
- g) indicazione dei motivi che giustificano l'omissione della notifica del progetto di regola tecnica all'Organizzazione mondiale del commercio ai sensi degli Accordi sulle barriere tecniche al commercio (Technical Barriers to Trade-TBT) e sull'applicazione di misure sanitarie e fitosanitarie (Sanitary and Phytosanitary Agreement-SPS), ovvero richiesta di notifica ai sensi di tali Accordi internazionali.

3. Per i progetti di regole tecniche contenuti in provvedimenti, anche con valore o forza di legge, ovvero di iniziativa legislativa, di competenza del Consiglio dei ministri, la trasmissione all'Unita' centrale di notifica di cui al comma 1 e gli altri adempimenti previsti dalla presente legge a carico dell'amministrazione competente sono effettuati a cura del Ministero proponente con competenza istituzionale prevalente per la materia.

4. Per i progetti di regole tecniche contenuti in proposte di legge di iniziativa parlamentare la trasmissione all'Unita' centrale di notifica di cui al comma 1 e gli altri adempimenti previsti dalla presente legge a carico dell'amministrazione competente sono effettuati a cura del Ministero con competenza istituzionale prevalente per la materia.

5. L'obbligo di trasmissione all'Unita' centrale di notifica ai fini della comunicazione alla Commissione europea di cui al comma 1 si applica anche alle regioni e alle province autonome, ed alle Autorita' cui e' riconosciuta la competenza di adottare regole tecniche applicabili in una parte importante del territorio nazionale; l'elenco di tali soggetti, pubblicato nella Gazzetta Ufficiale dell'Unione europea Serie C-127, del 31 maggio 2006, quando aggiornato su proposta delle Amministrazioni con competenza istituzionale prevalente per materia e del Ministero dello sviluppo economico, e' comunicato alla Commissione europea dal Dipartimento per le politiche europee della Presidenza del Consiglio dei ministri; resta fermo che l'organo o l'ufficio regionale competente ai relativi adempimenti sono individuati autonomamente secondo i rispettivi ordinamenti.

6. L'Unita' centrale di notifica provvede alla comunicazione di cui al comma 1, curando che tale comunicazione del progetto di regola tecnica alla Commissione europea sia completa di tutti gli elementi prescritti e della relativa documentazione, ed espleta gli adempimenti in merito previsti dall'articolo 9-bis.

7. L'Unita' centrale di notifica, anche su richiesta delle amministrazioni competenti che hanno trasmesso il progetto di regola tecnica ai fini della comunicazione di cui al comma 1 o che trasmettono osservazioni o pareri sui progetti di regole tecniche presentati da altri Stati membri dell'Unione europea, puo' chiedere, nei casi in cui il progetto di regola tecnica presenta aspetti che interessano piu' amministrazioni, di convocare presso il Dipartimento per le politiche europee della Presidenza del Consiglio dei ministri apposite riunioni di coordinamento anche ai fini della verifica della completezza e coerenza delle comunicazioni da trasmettere alla Commissione europea.

8. Nel preambolo o nel testo di una regola tecnica e del relativo progetto rientranti nel campo di applicazione della procedura di informazione preventiva di cui alla presente legge e' contenuto un riferimento alla direttiva (UE) 2015/1535.

9. Se un progetto di regola tecnica fa parte di una misura la cui comunicazione in fase di progetto e' prevista da un altro atto dell'Unione europea, e l'amministrazione competente non intende avvalersi della facolta' di effettuare la comunicazione ai sensi di tale altro atto dell'Unione europea attraverso lo sportello unico di notifica gestito dall'Unita' centrale di notifica, facendone richiesta come previsto al comma 2, lettera f), puo' effettuare anche la comunicazione di cui al comma 1 in forza di tale altro atto e secondo la procedura ivi prevista, a condizione di indicare formalmente che essa vale anche ai fini della direttiva (UE) 2015/1535 e di darne contestuale informazione all'Unita' centrale di notifica ed al Dipartimento delle politiche europee della Presidenza del Consiglio dei ministri. Al fine dell'assegnazione del numero e della data di notifica ai sensi della direttiva (UE) 2015/1535 del progetto di regole tecniche comunicato dalla amministrazione competente secondo la procedura prevista da altri atti dell'Unione europea, l'Unita' centrale di notifica provvede tempestivamente a comunicare il medesimo progetto di regola tecnica attraverso il sistema pratico scelto dalla Commissione in attuazione dell'articolo 3, paragrafo 4, lettera a), della direttiva (UE) 2015/1535 per lo scambio di informazioni.

10. Quando il progetto di regola tecnica mira in particolare a limitare la commercializzazione o l'utilizzazione di una sostanza, di un preparato o di un prodotto chimico, segnatamente per motivi di salute pubblica o di tutela dei consumatori o dell'ambiente, l'amministrazione competente trasmette all'Unita' centrale di notifica ai fini della comunicazione di cui al comma 1 anche un riassunto oppure gli estremi dei dati pertinenti relativi alla sostanza, al preparato o al prodotto in questione e di quelli relativi ai prodotti di sostituzione conosciuti e disponibili, se tali informazioni sono disponibili, nonche' le conseguenze previste delle misure per quanto riguarda la salute pubblica o la tutela del consumatore e dell'ambiente, con un'analisi dei rischi effettuata, all'occorrenza, secondo i principi previsti nella parte corrispondente della sezione II.3 dell'allegato XV del regolamento (CE) n. 1907/2006 del Parlamento e del Consiglio.

))

## Art. 6.

(( (Comunicazione delle informazioni da parte del Ministero dello sviluppo economico).)) ((

1. I progetti di regola tecnica di altri Stati membri dell'Unione europea comunicati dalla Commissione europea e le altre informazioni acquisite dall'Unita' centrale di notifica nel corso della procedura europea di informazione nel settore delle regolamentazioni tecniche e delle regole relative ai servizi della societa' dell'informazione sono poste a disposizione delle altre amministrazioni pubbliche interessate. Il Ministero dello sviluppo economico definisce le modalita' per assicurare il flusso delle informazioni, anche mediante sistemi di posta elettronica. Ove non si tratta di informazioni riservate ai sensi dell'articolo 5, paragrafo 4, della direttiva (UE) 2015/1535, il Ministero dello sviluppo economico e' tenuto a facilitare l'accesso alle informazioni pubblicate dalla Commissione europea nel proprio sito web dedicato alla procedura di informazione da parte degli utenti, singoli od associati, anche attraverso l'ausilio di adeguati supporti informatici. L'accesso alle comunicazioni da e verso la Commissione europea gestite dalla medesima Unita' centrale di notifica in applicazione della procedura di informazione e non pubblicate nel sito web della Commissione europea dedicato alla procedura e' garantito, nel rispetto della disciplina vigente, dalle amministrazioni pubbliche che hanno formato o detengono stabilmente il documento. L'accesso alle suddette comunicazioni e' altresi' consentito nei confronti dell'Unita' centrale di notifica limitatamente alle sole amministrazioni ed autorita' pubbliche. Eventuali domande di accesso da parte di terzi a documenti gestiti in applicazione della procedura di informazione sono assoggettate alla disciplina derivante dal regolamento (CE) n. 1049/2001.

2. Le osservazioni o i pareri circostanziati formulati dalle altre amministrazioni pubbliche interessate su un progetto di regola tecnica presentato da altri Stati membri dell'Unione europea sono inviati all'Unita' centrale di notifica che li trasmette alla Commissione europea, tenendo conto dei risultati dell'eventuale coordinamento condotto ai sensi dell'articolo 5-bis, comma 7. Per quanto concerne le specificazioni tecniche o altri requisiti o le regole relative ai servizi, di cui all'articolo 1, comma 1, lettera f), numero 3), le osservazioni o i pareri circostanziati si basano unicamente sugli aspetti che costituiscono eventualmente ostacoli agli scambi o, per le regole relative ai servizi, alla libera circolazione dei servizi o alla liberta' di stabilimento dell'operatore di servizi, e non sugli elementi fiscali o finanziari della misura. Per quanto riguarda i progetti di regole tecniche relative ai servizi, i pareri circostanziati non possono pregiudicare misure di politica culturale, in particolare nel settore audiovisivo, che lo Stato membro dell'Unione europea che ha presentato il progetto puo' adottare secondo il diritto dell'Unione europea, tenendo conto della diversita' linguistica, delle specificita' nazionali e regionali, nonche' del proprio patrimonio culturale.

## Art. 7.

((ARTICOLO ABROGATO DAL D.LGS. 15 DICEMBRE 2017, N. 223))

## Art. 8. - (( (Contributo agli organismi nazionali di normazione italiani).))

((

1. Al fine di consentire l'adeguato svolgimento dell'attivita' di normazione tecnica, in particolare per la sicurezza degli impianti, prodotti, processi e servizi, e un'adeguata partecipazione alle attivita' di cooperazione europea ed internazionale in materia e di promozione della cultura della normativa tecnica, di contenere comunque i costi di acquisto delle norme in particolare a vantaggio delle piccole e medie imprese, artigiani, ordini ed associazioni professionali nonche' di consentire al Ministero dello sviluppo economico di disporre l'eventuale pubblicazione gratuita di norme di particolare interesse pubblico, il Ministero dello sviluppo economico concede agli organismi nazionali di normazione italiani un contributo annuo determinato forfettariamente nei limiti delle disponibilita' di cui al comma 2 ed in misura pari al 67 per cento di tali disponibilita' per l'UNI e del 33 per cento per il CEI. Tale contributo, tenendo conto di quanto corrisposto anche a titolo di eventuale anticipazione in ciascun anno e degli eventuali conguagli operati nell'anno successivo, mantiene il carattere di cofinanziamento rispetto alle entrate proprie per ricavi da vendite delle norme e per contributi privati e eventualmente dell'Unione europea e non puo' a tal fine comunque eccedere il 50 per cento dei costi iscritti nel bilancio di UNI e CEI nell'esercizio precedente relativamente allo svolgimento delle funzioni istituzionali. Il Ministero dello sviluppo economico puo' adottare direttive circa le priorita' e le ulteriori finalita' cui destinare il predetto contributo.

2. La concessione e l'erogazione dei contributi di cui al comma 1 e' posta a carico delle somme annualmente iscritte nell'apposito capitolo dello stato di previsione della spesa del Ministero dello sviluppo economico ai sensi dell'articolo 2, comma 617-bis, della legge 24 dicembre 2007, n. 244, e di cui all'articolo 23, comma 1-bis, della legge 31 dicembre 2009, n. 196. Per le finalita' previste dal presente comma, il tre per cento del contributo dovuto annualmente dall'Istituto nazionale per l'assicurazione contro gli infortuni sul lavoro (INAIL) per l'attivita' di ricerca di cui all'articolo 3, terzo comma, del decreto-legge 30 giugno 1982, n. 390, convertito, con modificazioni, dalla legge 12 agosto 1982, n. 597, e' versato all'entrata del bilancio dello Stato.

3. Il Ministero dello sviluppo economico trasmette al Parlamento una relazione annuale con la quale viene illustrato l'utilizzo da parte di UNI e CEI delle somme ricevute a titolo di contributo.

))

## Art. 9. - (( (Differimento dell'adozione di regole tecniche).))

((

1. L'adozione di un progetto di regola tecnica e' rinviata di tre mesi a decorrere dalla data di notifica.

2. Se la Commissione europea o un altro Stato membro emette, nei tre mesi successivi alla data di notifica, un parere circostanziato, l'adozione del progetto di regola tecnica e' rinviata a decorrere dalla data di notifica:

- a) di quattro mesi nel caso di un progetto di regola tecnica avente forma di accordo facoltativo a norma dell'articolo 1, comma 1, lettera f), numero 2), oggetto di un parere circostanziato secondo il quale la misura proposta presenta aspetti che possono eventualmente creare ostacoli alla libera circolazione delle merci nell'ambito del mercato interno;
- b) fatti salvi i commi 3 e 4, di sei mesi per qualsiasi altro progetto di regola tecnica, esclusi i progetti relativi ai servizi, oggetto di un parere circostanziato secondo il quale la misura proposta presenta aspetti che possono eventualmente creare ostacoli alla libera circolazione delle merci nell'ambito del mercato interno;
- c) fatto salvo il comma 4, di quattro mesi nel caso di un progetto di regola tecnica relativa ai servizi, oggetto di uno o piu' pareri circostanziati secondo il quale la misura proposta presenta aspetti che possono eventualmente creare ostacoli alla libera circolazione dei servizi o alla liberta' di stabilimento degli operatori di servizi nell'ambito del mercato interno, fermo restando che tali pareri non possono pregiudicare misure di politica culturale, in particolare nel settore audiovisivo, che gli Stati potrebbero adottare secondo il diritto dell'Unione, tenendo conto della loro diversita' linguistica, delle specificita' nazionali e regionali, nonche' dei loro patrimoni culturali.

3. L'adozione di un progetto di regola tecnica, esclusi i progetti di regole relative ai servizi, e' rinviata di dodici mesi a decorrere dalla data di notifica, se la Commissione europea, nei tre mesi successivi a tale data, comunica la sua intenzione di proporre o di adottare una direttiva, un regolamento o una decisione in materia a norma dell'articolo 288 TFUE. Se il Consiglio dell'Unione europea adotta una posizione in prima lettura durante il termine di differimento di cui al presente comma, tale periodo e' esteso a diciotto mesi fatte salve le disposizioni del comma 6.

4. L'adozione di un progetto di regola tecnica e' rinviata di 12 mesi a decorrere dalla data di notifica, se la Commissione europea, nei tre mesi successivi a tale data, comunica la constatazione che il progetto di regola tecnica concerne una materia oggetto di una proposta di direttiva, di regolamento o di decisione presentata al Parlamento europeo e del Consiglio conformemente all'articolo 288 TFUE. Se il Consiglio dell'Unione europea adotta una posizione in prima lettura durante il termine di differimento di cui al presente comma, tale periodo e' esteso a 18 mesi fatte salve le disposizioni del comma 6.

5. Gli obblighi di rinvio cui ai commi 3 e 4 cessano:

- a) se la Commissione europea informa che essa rinuncia alla sua intenzione di proporre o di adottare un atto vincolante;
- b) se la Commissione europea informa del ritiro della sua proposta o del suo progetto;
- c) all'adozione di un atto vincolante da parte del Parlamento europeo e del Consiglio o della Commissione europea.

6. I commi da 1 a 4 non sono applicabili nei casi in cui:

- a) per motivi urgenti giustificati da una situazione grave e imprevedibile inerente alla tutela della salute delle persone e degli animali, alla preservazione dei vegetali o alla sicurezza e, per le regole relative ai servizi, giustificati anche da motivi di ordine pubblico, in particolare in materia di tutela dei minori, e' necessario elaborare in tempi brevissimi regole tecniche da adottare e mettere in vigore con effetto immediato, senza alcuna possibilita' di consultazione; oppure;
- b) per motivi urgenti giustificati da una situazione grave inerente alla tutela della sicurezza e integrita' del sistema finanziario e in particolare ai fini della tutela dei depositanti, degli investitori e degli assicurati, e' necessario adottare e mettere in vigore in tempi brevissimi regole relative ai servizi finanziari.

))

## Art. 9-bis. - (( (Adempimenti procedurali).))

((

1. Ai fini dell'applicazione dell'articolo 9, l'Unita' centrale di notifica informa l'amministrazione che ha trasmesso il progetto di regola tecnica per la comunicazione di cui all'articolo 5-bis, comma 1, della sua comunicazione alla Commissione europea e della data di scadenza del termine di tre mesi di cui all'articolo 9, comma 1, nonche' del numero assegnato dalla Commissione alla notifica.

2. Se durante il periodo di cui all'articolo 9, comma 1, la Commissione europea trasmette all'Unita' centrale di notifica osservazioni su un progetto di regola tecnica formulate dalla Commissione medesima o da un altro Stato membro dell'Unione europea, l'Unita' centrale di notifica ne informa tempestivamente l'amministrazione di cui al comma 1 affinche' formuli una risposta da inviare alla Commissione, tramite la stessa Unita' centrale di notifica, nella quale e' indicato se ed in quale misura e' possibile tenere conto delle osservazioni nella stesura definitiva della regola tecnica.

3. Se durante il periodo di cui all'articolo 9, comma 1, la Commissione europea trasmette all'Unita' centrale di notifica un parere circostanziato su un progetto di regola tecnica formulato dalla Commissione medesima o da un altro Stato membro dell'Unione europea, l'Unita' centrale di notifica informa tempestivamente l'amministrazione di cui al comma 1, comunicando anche il nuovo termine di differimento dell'adozione della regola tecnica ai sensi dell'articolo 9. Con congruo anticipo rispetto a tale nuovo termine detta amministrazione formula una reazione al parere circostanziato, da inviare alla Commissione europea tramite l'Unita' centrale di notifica, nella quale, per ottemperare all'obbligo di riferire alla Commissione sul seguito che l'Italia intende dare a tale parere circostanziato sono indicate le modifiche che propone di apportare al progetto per conformarlo al parere circostanziato.

4. Se il progetto riguarda regole relative ai servizi e l'amministrazione di cui al comma 1 valuta impossibile tenere conto del parere circostanziato, essa formula una risposta, da inviare alla Commissione europea tramite l'Unita' centrale di notifica, nella quale, per ciascuno degli aspetti contestati, sono indicati i motivi per i quali non e' possibile tenerne conto nella stesura definitiva della regola tecnica.

5. L'Unita' centrale di notifica comunica all'amministrazione di cui al comma 1 i commenti che la Commissione europea formula sulle reazioni dell'Italia ai pareri circostanziati di cui ai commi 3 e 4 e gli eventuali commenti sulle risposte alle osservazioni di cui al comma 2.

6. Se durante il periodo di cui all'articolo 9, comma 1, la Commissione europea trasmette all'Unita' centrale di notifica comunicazioni ai sensi dell'articolo 9, commi 3, 4 e 5 su un progetto di regola tecnica, l'Unita' centrale di notifica ne informa tempestivamente l'amministrazione di cui al comma 1, comunicando anche il nuovo termine di differimento dell'adozione della regola tecnica ai sensi dell'articolo 9.

7. Le comunicazioni dell'Unita' centrale di notifica di cui ai commi 1, 2, 3, 5 e 6 all'amministrazione che ha trasmesso il progetto di regola tecnica sono inviate anche al Ministro per i rapporti con il Parlamento che, entro quindici giorni dalla ricezione, le trasmette alla Camera dei deputati e al Senato della Repubblica. Le comunicazioni di cui al presente comma sono effettuate altresi' al Presidente del Consiglio o ad un Ministro da lui delegato nel caso di progetti di regole tecniche contenuti in provvedimenti, anche con valore o forza di legge, nel caso di iniziativa legislativa da sottoporre all'esame del Consiglio dei Ministri, ovvero nel caso di disegni di legge di iniziativa governativa all'esame del Parlamento.

8. Al fine di non incorrere nell'apertura da parte della Commissione europea di procedure di infrazione ai sensi dell'articolo 258 del Trattato sul funzionamento dell'Unione europea, anche nel caso di progetti di regole tecniche di cui al comma 7, deve essere adottata ogni iniziativa necessaria per garantire che la regola tecnica comunicata alla Commissione ai sensi della direttiva (UE) 2015/1535 venga adottata nel rispetto dei termini e vincoli procedurali che la medesima direttiva impone agli Stati membri dell'Unione europea. Copia del provvedimento definitivo che adotta una regola tecnica rientrante nel campo d'applicazione della presente legge e' trasmessa all'Unita' centrale di notifica, all'atto della sua pubblicazione o diramazione ufficiale, dall'amministrazione di cui al comma 1; l'Unita' centrale di notifica ne cura la trasmissione alla Commissione europea.

))

## Art. 9-ter. - (( (Esclusione di adempimenti).))

((

1. Gli articoli 5-bis e 9 non si applicano alle disposizioni legislative, regolamentari ed amministrative o agli accordi facoltativi che:

- a) si conformano agli atti vincolanti dell'Unione europea che danno luogo all'adozione di specificazioni tecniche o di regole relative ai servizi;
- b) soddisfano gli impegni derivanti da un accordo internazionale, che danno luogo all'adozione di specificazioni tecniche o di regole comuni relative ai servizi comuni nell'Unione europea;
- c) fanno uso di clausole di salvaguardia previste in atti vincolanti dell'Unione europea;
- d) applicano l'articolo 12, paragrafo 1, della direttiva 2001/95/CE del Parlamento europeo e del Consiglio sulla sicurezza generale dei prodotti come attuato nell'articolo 110 del decreto legislativo 6 settembre 2005, n. 206;
- e) si limitano ad eseguire una sentenza della Corte di giustizia dell'Unione europea;
- f) si limitano a modificare una regola tecnica di cui all'articolo 1, comma 1, lettera f), in conformita' di una domanda della Commissione europea diretta ad eliminare un ostacolo agli scambi o, per le regole relative ai servizi, alla libera circolazione dei servizi o alla liberta' di stabilimento dell'operatore di servizi.

2. L'articolo 9 non si applica alle disposizioni legislative, regolamentari e amministrative recanti divieti di fabbricazione, nella misura in cui esse non ostacolano la libera circolazione dei prodotti, e alle specificazioni tecniche o ad altri requisiti o alle regole relative ai servizi di cui all'articolo 1, comma 1, lettera f), numero 3).

3. L'articolo 9, commi 3, 4 e 5, non si applica agli accordi facoltativi di cui all'articolo 1, comma 1, lettera f), numero 2) ))

## Art. 10. - Disposizioni finanziarie

1. All'onere derivante dall'attuazione della presente legge, valutato in lire 200 milioni in ragione d'anno, si provvede mediante corrispondente riduzione dello stanziamento iscritto, ai fini del bilancio triennale 1986-1988, al capitolo 6856 dello stato di previsione del Ministero del tesoro per l'anno finanziario 1986, all'uopo utilizzando lo specifico accantonamento.

2. Il Ministro del tesoro e' autorizzato ad apportare, con propri decreti, le occorrenti variazioni di bilancio.

## Art. 11.

((ARTICOLO ABROGATO DAL D.LGS. 15 DICEMBRE 2017, N. 223))

